pub struct CancellationNotification {
pub request_id: CancellationRequestId,
/* private fields */
}Expand description
Final notifications/cancelled payload.
Fields
request_id: CancellationRequestIdRequired non-null request identifier.
Implementations
Sourceimpl CancellationNotification
impl CancellationNotification
Sourcepub fn try_new(
request_id: CancellationRequestId,
reason: Option<String>,
) -> Result<Self, CommonTypeError>
pub fn try_new( request_id: CancellationRequestId, reason: Option<String>, ) -> Result<Self, CommonTypeError>
Constructs an exact cancellation payload while retaining an untrusted reason without rendering or interpreting it.
Sourcepub fn has_untrusted_reason(&self) -> bool
pub fn has_untrusted_reason(&self) -> bool
Indicates whether a peer reason was present without rendering or exposing it.