pub enum CacheTtlConversionError {
Negative,
RuntimeOutOfRange,
}Expand description
Failure while validating or converting a final cache TTL.
Variants
Negative
The wire integer is mathematically negative.
RuntimeOutOfRange
The wire integer is valid but exceeds the local u64 runtime domain.