pub enum FinalArguments<T> {
Absent,
Value(T),
}Expand description
Wire presence of an optional final request arguments member.
Variants
Absent
The arguments member was not present on the wire.
Value(T)
The member was present with its admitted typed value.
Implementations
Sourceimpl<T> FinalArguments<T>
impl<T> FinalArguments<T>