pub enum FinalEmbeddedInputResponse {
Sampling(FinalCreateMessageResult),
Roots(FinalEmbeddedRootsListResult),
Elicitation(FinalEmbeddedElicitationResult),
}Expand description
A final MRTR result payload embedded in a Task, without a JSON-RPC envelope.
Variants
Sampling(FinalCreateMessageResult)
Sampling result payload.
Roots(FinalEmbeddedRootsListResult)
Roots-list result payload.
Elicitation(FinalEmbeddedElicitationResult)
Elicitation result payload. The request ledger determines form versus URL.
Implementations
Sourceimpl FinalEmbeddedInputResponse
impl FinalEmbeddedInputResponse
Sourcepub fn matches_kind(&self, kind: FinalEmbeddedInputKind) -> bool
pub fn matches_kind(&self, kind: FinalEmbeddedInputKind) -> bool
Returns whether this response can answer the supplied descriptor kind.