pub enum McpAppsLifecycleError {
InvalidTransition {
from: McpAppsViewLifecycle,
operation: &'static str,
},
}Expand description
Illegal transition in the pure Apps View lifecycle state machine.
Variants
InvalidTransition
The requested operation is not legal from the retained lifecycle phase.
Fields

from: McpAppsViewLifecycleCurrent lifecycle phase.