pub enum McpAppsResourceBindingError {
UriMismatch,
HtmlMimeTypeRequired,
Metadata(McpAppsMetadataError),
}Expand description
A catalog resource did not satisfy one validated Apps binding.
Variants
UriMismatch
The candidate resource URI differs from the tool’s exact binding URI.
HtmlMimeTypeRequired
The candidate resource is not an Apps HTML resource.
Metadata(McpAppsMetadataError)
Resource metadata was not a valid closed Apps metadata object.