pub enum ProgressMarker {
String(String),
Number(i64),
}Expand description
Progress marker used to correlate progress notifications with requests.
Per MCP spec, progress markers can be either strings or integers.
Variants