pub enum ProgressToken {
String(String),
Number(i64),
}Expand description
Progress token used to correlate progress notifications with requests.
Per MCP spec, progress tokens can be either strings or integers.
Variants