pub enum ExtensionDirection {
ClientToServer,
ServerToClient,
}Expand description
Direction of a registered RPC name.
Variants
ClientToServer
A client sends a request or notification to a server.
ServerToClient
A server sends a request or notification to a client.