pub enum Final2026EnvelopeKind {
Request,
Notification,
}Expand description
JSON-RPC envelope kind required by an active MCP 2026-07-28 core method.
Variants
Request
The method is a request and therefore requires a non-null request ID.
Notification
The method is a notification and therefore must omit its request ID.