pub enum Legacy2024EnvelopeKind {
Request,
Notification,
}Expand description
JSON-RPC envelope kind required for a tagged method.
Variants
Request
The method is a request and therefore requires a non-null request ID.
Notification
The method is a notification and therefore must omit its request ID.