pub struct Final2026Method {
pub name: &'static str,
pub direction: Final2026Direction,
pub envelope: Final2026EnvelopeKind,
}Expand description
Exact direction and envelope metadata for one active MCP 2026-07-28 core method.
Fields
name: &'static strExact JSON-RPC method literal.
direction: Final2026DirectionPeer direction admitted by the active final core union.
envelope: Final2026EnvelopeKindRequest-versus-notification envelope constraint.
Implementations
Sourceimpl Final2026Method
impl Final2026Method
Sourcepub const fn admits_notification_from(self, peer: Final2026Peer) -> bool
pub const fn admits_notification_from(self, peer: Final2026Peer) -> bool
Returns whether this method is a notification admitted from peer.