pub enum HttpEndpointBundleError {
MissingModernPostTarget {
policy: ProtocolPolicy,
},
MissingLegacySseTarget {
policy: ProtocolPolicy,
},
MissingLegacyMessagePostTarget {
policy: ProtocolPolicy,
},
FragmentNotAllowed {
route: HttpRouteKind,
},
RouteCollision {
first: HttpRouteKind,
second: HttpRouteKind,
target: String,
},
}Expand description
Typed refusal while constructing a configured HTTP endpoint bundle.
Variants
MissingModernPostTarget
A policy requiring modern HTTP lacked its explicit configured POST target.
Fields

policy: ProtocolPolicyThe rejected policy.
MissingLegacySseTarget
A policy requiring legacy HTTP lacked its configured SSE GET target.
Fields

policy: ProtocolPolicyThe rejected policy.
MissingLegacyMessagePostTarget
A policy requiring legacy HTTP lacked its configured message POST target.
Fields

policy: ProtocolPolicyThe rejected policy.
FragmentNotAllowed
A configured endpoint contained a fragment, which is never sent in HTTP.
Fields

route: HttpRouteKindThe route that supplied the invalid target.
RouteCollision
Two configured routes have the same method and exact canonical target.
Fields

first: HttpRouteKindThe first colliding route.

second: HttpRouteKindThe second colliding route.