pub enum HttpProbeBody {
RecognizedModernJsonRpc,
Empty,
Unrecognized,
TransportFailure,
}Expand description
The body category returned by one isolated modern HTTP probe.
Variants
RecognizedModernJsonRpc
A recognized modern JSON-RPC result or error object.
Empty
An empty response body.
Unrecognized
A body that is not a recognized modern JSON-RPC result or error.
TransportFailure
No response was received because of a transport failure.