pub enum StdioEraState {
Unclassified,
Selected(ProtocolEra),
TerminalWithoutEra,
}Expand description
The state of one server-side stdio process’s immutable era selection.
Variants
Unclassified
Auto policy has not yet received a structurally valid opening request.
Selected(ProtocolEra)
The process selected this era and cannot select again.
TerminalWithoutEra
An invalid opening closed the process without selecting an era.