pub struct HttpEndpointBundle { /* private fields */ }Expand description
Immutable, configured HTTP endpoint bundle for one policy selection.
Implementations
Sourceimpl HttpEndpointBundle
impl HttpEndpointBundle
Sourcepub fn new(
policy: ProtocolPolicy,
modern_post: Option<CanonicalHttpUrl>,
legacy_sse: Option<CanonicalHttpUrl>,
legacy_message_post: Option<CanonicalHttpUrl>,
credential_partition: String,
security_partition: String,
transport_profile: String,
policy_generation: u64,
configuration_generation: u64,
legacy_receipt_generation: u64,
) -> Result<Self, HttpEndpointBundleError>
pub fn new( policy: ProtocolPolicy, modern_post: Option<CanonicalHttpUrl>, legacy_sse: Option<CanonicalHttpUrl>, legacy_message_post: Option<CanonicalHttpUrl>, credential_partition: String, security_partition: String, transport_profile: String, policy_generation: u64, configuration_generation: u64, legacy_receipt_generation: u64, ) -> Result<Self, HttpEndpointBundleError>
Builds a trusted bundle exclusively from configured canonical targets.
Sourcepub fn key(&self) -> HttpEndpointBundleKey
pub fn key(&self) -> HttpEndpointBundleKey
Returns the immutable opaque cache key for this configured bundle.