pub struct HttpEraCache { /* private fields */ }Expand description
Per-bundle era cache that cannot be contaminated by origin-only matches.
Implementations
Sourceimpl HttpEraCache
impl HttpEraCache
Sourcepub fn classify_or_cached(
&mut self,
bundle: &HttpEndpointBundle,
probe: HttpModernProbe,
) -> HttpEraDecision
pub fn classify_or_cached( &mut self, bundle: &HttpEndpointBundle, probe: HttpModernProbe, ) -> HttpEraDecision
Classifies one configured bundle once or returns its immutable cached era.
Sourcepub fn invalidate(&mut self, key: &HttpEndpointBundleKey) -> Option<ProtocolEra>
pub fn invalidate(&mut self, key: &HttpEndpointBundleKey) -> Option<ProtocolEra>
Explicit trusted invalidation removes only one exact bundle key.
Sourcepub fn selected_era(&self, key: &HttpEndpointBundleKey) -> Option<ProtocolEra>
pub fn selected_era(&self, key: &HttpEndpointBundleKey) -> Option<ProtocolEra>
Returns an era only for the exact full bundle key.