CompleteResult

Struct CompleteResult 

pub struct CompleteResult<T> {
    pub payload: T,
    pub meta: ResultMeta,
    pub extras: UnknownResultMembers,
}
A typed core complete result with inert open siblings.

Fields

payload: T

Method-specific complete payload.

meta: ResultMeta

Common result metadata.

extras: UnknownResultMembers

Open siblings that did not belong to the selected complete composition.

Implementations

Source

impl<T> CompleteResult<T>

pub fn new(payload: T, meta: ResultMeta) -> Self

Creates a strict complete result. Serialization always emits resultType: "complete".