pub struct FinalToolAnnotations {
pub title: Option<String>,
pub destructive: Option<bool>,
pub idempotent: Option<bool>,
pub read_only: Option<bool>,
pub open_world_hint: Option<bool>,
}Expand description
Final tool annotations, including the final display-title hint.
Fields
title: Option<String>Optional display title, lower priority than the enclosing tool title.
destructive: Option<bool>Whether the tool may perform destructive updates.
idempotent: Option<bool>Whether repeated calls are idempotent.
read_only: Option<bool>Whether the tool is read-only.
open_world_hint: Option<bool>Whether the tool may interact with an open world.