JsonRpcResponse

Struct JsonRpcResponse 

pub struct JsonRpcResponse {
    pub jsonrpc: Cow<'static, str>,
    pub result: Option<Value>,
    pub error: Option<JsonRpcError>,
    pub id: Option<RequestId>,
}
JSON-RPC 2.0 response.

Fields

jsonrpc: Cow<'static, str>

Protocol version (always “2.0”).

result: Option<Value>

Result (present on success, including an explicit JSON null).

error: Option<JsonRpcError>

Error (present on failure).

id: Option<RequestId>

Request ID this is responding to.

Implementations

Source

impl JsonRpcResponse

pub fn success(id: RequestId, result: Value) -> Self

Creates a success response.

pub fn error(id: Option<RequestId>, error: JsonRpcError) -> Self

Creates an error response.

pub fn is_error(&self) -> bool

Returns true if this is an error response.

pub fn validate(&self) -> Result<(), &'static str>

Verifies invariants that can otherwise be bypassed by constructing or mutating this public protocol type directly.

Errors

Returns an error unless the protocol version is exact, exactly one outcome member is present, every ID is valid, and success is correlated to a request ID.