pub enum ProgressMarker {
String(String),
Number(JsonInteger),
}Expand description
Progress marker used to correlate progress notifications with requests.
Per MCP spec, progress markers can be either strings or arbitrary-width JSON integers.
Variants
String(String)
String progress marker.
Number(JsonInteger)
Arbitrary-width JSON integer progress marker.