pub enum ServerBehavior {
LoggingRequestEmitter,
CompletionComplete,
ToolsList,
ToolsListChangedNotification,
ResourcesList,
ResourcesListChangedNotification,
ResourcesSubscribe,
SubscriptionsListen,
ResourceUpdateDelivery,
PromptsList,
PromptsListChangedNotification,
}Expand description
A server behavior whose installation can be advertised through discovery.
Variants
LoggingRequestEmitter
The deprecated logging/request emitter is installed.
CompletionComplete
The completion/complete dispatch target is installed.
ToolsList
The tools/list dispatch target is installed.
ToolsListChangedNotification
The notifications/tools/list_changed producer is installed.
ResourcesList
The resources/list dispatch target is installed.
ResourcesListChangedNotification
The notifications/resources/list_changed producer is installed.
ResourcesSubscribe
The resources/subscribe dispatch target is installed.
SubscriptionsListen
The subscription listener used by resource subscriptions is installed.
ResourceUpdateDelivery
The resource-update delivery path is installed.
PromptsList
The prompts/list dispatch target is installed.
PromptsListChangedNotification
The notifications/prompts/list_changed producer is installed.