pub struct CompleteResult<T> {
pub payload: T,
pub meta: ResultMeta,
pub extras: UnknownResultMembers,
}Expand description
A typed core complete result with inert open siblings.
Fields
payload: TMethod-specific complete payload.
meta: ResultMetaCommon result metadata.
extras: UnknownResultMembersOpen siblings that did not belong to the selected complete composition.
Implementations
Sourceimpl<T> CompleteResult<T>
impl<T> CompleteResult<T>
Sourcepub fn new(payload: T, meta: ResultMeta) -> Self
pub fn new(payload: T, meta: ResultMeta) -> Self
Creates a strict complete result. Serialization always emits
resultType: "complete".