ToolAnnotations

Struct ToolAnnotations 

pub struct ToolAnnotations {
    pub destructive: Option<bool>,
    pub idempotent: Option<bool>,
    pub read_only: Option<bool>,
    pub open_world_hint: Option<String>,
}
Tool annotations for additional metadata.

These annotations provide hints about tool behavior to help clients make informed decisions about tool usage.

Fields

destructive: Option<bool>

Whether the tool may cause destructive side effects. True means the tool modifies external state (e.g., deleting files).

idempotent: Option<bool>

Whether the tool is idempotent (safe to retry without side effects). True means calling the tool multiple times has the same effect as calling it once.

read_only: Option<bool>

Whether the tool is read-only (has no side effects). True means the tool only reads data without modifying anything.

open_world_hint: Option<String>

Hint about the tool’s behavior with unknown inputs. Can be used to indicate how the tool handles inputs not explicitly defined.

Implementations

Source

impl ToolAnnotations

pub fn new() -> Self

Creates a new empty annotations struct.

pub fn destructive(self, value: bool) -> Self

Sets the destructive annotation.

pub fn idempotent(self, value: bool) -> Self

Sets the idempotent annotation.

pub fn read_only(self, value: bool) -> Self

Sets the read_only annotation.

pub fn open_world_hint(self, hint: impl Into<String>) -> Self

Sets the open_world_hint annotation.

pub fn is_empty(&self) -> bool

Returns true if any annotation is set.